@@ -20,12 +20,16 @@ FILE = 9
 DATE = 10
 DATE_TIME = 11
 HIDDEN = 12
+NUMBER = 13
+URL = 14
 
 # Names for all available field types.
 NAMES = (
     (TEXT, _("Single line text")),
     (TEXTAREA, _("Multi line text")),
     (EMAIL, _("Email")),
+    (NUMBER, _("Number")),
+    (URL, _("URL")),
     (CHECKBOX, _("Check box")),
     (CHECKBOX_MULTIPLE, _("Check boxes")),
     (SELECT, _("Drop down")),
@@ -51,6 +55,8 @@ CLASSES = {
     DATE: forms.DateField,
     DATE_TIME: forms.DateTimeField,
     HIDDEN: forms.CharField,
+    NUMBER: forms.FloatField,
+    URL: forms.URLField,
 }
 
 # Widgets for field types where a specialised widget is required.
@@ -75,4 +81,6 @@ if settings.FORMS_USE_HTML5:
         DATE: html5_field("date", forms.DateInput),
         DATE_TIME: html5_field("datetime", forms.DateTimeInput),
         EMAIL: html5_field("email", forms.TextInput),
+        NUMBER: html5_field("number", forms.TextInput),
+        URL: html5_field("url", forms.TextInput),
     })
