@@ -153,8 +153,8 @@ LOGOUT_URL = "/account/logout/"
 
 DATABASES = {
     "default": {
-        # "postgresql_psycopg2", "postgresql", "mysql", "sqlite3" or "oracle".
-        "ENGINE": "",
+        # Add "postgresql_psycopg2", "mysql", "sqlite3" or "oracle".
+        "ENGINE": "django.db.backends.",
         # DB name or path to database file if using sqlite3.
         "NAME": "",
         # Not used with sqlite3.
@@ -163,7 +163,7 @@ DATABASES = {
         "PASSWORD": "",
         # Set to empty string for localhost. Not used with sqlite3.
         "HOST": "",
-         # Set to empty string for default. Not used with sqlite3.
+        # Set to empty string for default. Not used with sqlite3.
         "PORT": "",
     }
 }
